"""
:author: Parliskaya
:license: MIT License, see LICENSE file

:copyright: (c) 2022 Parliskaya
"""

from .openvkapi import *
from .account import account
from .friends import friends
from .groups import groups
from .messages import messages
from .ovk import ovk
from .utils import utils
from .users import users
from .news_feed import news_feed
from .wall import wall
from .likes import likes


__author__ = 'Parliskaya'
__version__ = '1.4'
__email__ = 'alonaparlis@gmail.com'